﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Text;
using System.Web.Mvc;
using System.Web.Mvc.Html;

namespace Benday.BootstrapDebugger
{
    public static class ExtensionMethods
    {
        public static MvcHtmlString DisplayBootstrapColumnDebugRow<TModel>(this HtmlHelper<TModel> html)
        {
            var divTemplate =
                "<div class='col-sm-1 col-md-1 col-lg-1' style='border-style: dotted'>{0}</div>";

            var builder = new StringBuilder();

            builder.AppendLine("<div class='row'>");

            for (var i = 1; i <= 12; i++)
            {
                builder.AppendFormat(divTemplate, i);
                builder.AppendLine();
            }

            builder.AppendLine("</div>");

            return new MvcHtmlString(builder.ToString());
        }

        public static MvcForm BeginBootstrapForm(this HtmlHelper helper)
        {
            return helper.BeginForm(null, null, FormMethod.Post, new
            { @class = "well form-search" });
        }

        public static MvcForm BeginBootstrapForm(this HtmlHelper helper, FormMethod method)
        {
            return helper.BeginForm(null, null, method, new
            { @class = "well form-search" });
        }

        public static MvcForm BeginBootstrapForm(this HtmlHelper helper, string actionName)
        {
            return helper.BeginForm(actionName, null, FormMethod.Get, new
            { @class = "well form-search" });
        }

        public static MvcHtmlString EditorForBootstrap<TModel, TValue>(this HtmlHelper<TModel> html, Expression<Func<TModel, TValue>> expression)
        {
            var returnValue = html.EditorFor<TModel, TValue>(expression,
                additionalViewData: new
            { htmlAttributes = new
            { @class = "form-control" } });

            return returnValue;
        }

        public static MvcHtmlString LabelForWithClassAttribute<TModel, TValue>(this HtmlHelper<TModel> html,
            Expression<Func<TModel, TValue>> expression, string classAttributeValue)
        {
            var returnValue = html.LabelFor<TModel, TValue>(expression,
                new
            { @class = classAttributeValue });

            return returnValue;
        }

        public static MvcHtmlString EditorForWithClassAttribute<TModel, TValue>(this HtmlHelper<TModel> html,
            Expression<Func<TModel, TValue>> expression, string classAttributeValue)
        {
            var returnValue = html.EditorFor<TModel, TValue>(expression,
                additionalViewData: new
            { htmlAttributes = new
            { @class = classAttributeValue } });

            return returnValue;
        }

        public static MvcHtmlString EditorForWithClassAttribute<TModel, TValue>(this HtmlHelper<TModel> html,
            Expression<Func<TModel, TValue>> expression, string classAttributeValue, int rows)
        {
            var returnValue = html.EditorFor<TModel, TValue>(expression,
                additionalViewData: new
            {
                    htmlAttributes = new
            {
                        @class = classAttributeValue,
                        @rows = rows
                    }
                });

            return returnValue;
        }
    }
}
